==> hSDM_1.0.tar.gz: hSDM/README.md <==
hSDM R package
===============

`hSDM` is an R package for estimating parameters of hierarchical
Bayesian species distribution models. Such models allow interpreting
the observations (occurrence and abundance of a species) as a result
of several hierarchical processes including ecological processes
(habitat suitability, spatial dependence and anthropogenic
disturbance) and observation processes (species
detectability). Hierarchical species distribution models are essential
for accurately characterizing the environmental response of species,
predicting their probability of occurrence, and assessing uncertainty
in the model results.

Code and manual
---------------

The last stable version of the `hSDM` R package is officially
available for several operating systems (Unix, Windows and Mac OSX) on
the Comprehensive R Archive Network
([CRAN](http://cran.r-project.org/web/packages/hSDM/index.html)).

Acknowledgments
--------------

We gratefully acknowledge Shanshan Wu for the original C++ code used
in Latimer et al. 2006.

Related publications
--------------------

**Latimer, A. M.; Wu, S. S.; Gelfand, A. E. & Silander, J. A.** 2006.
Building statistical models to analyze species distributions.
*Ecological Applications.* **16**(1): 33-50.

**Gelfand A. E., Silander J. A., Wu S. S., Latimer A., Lewis P. O.,
Rebelo A. G. and Holder M.** 2006. Explaining species distribution
patterns through hierarchical modeling. *Bayesian Analysis.* **1**(1):
41-92.

**Diez J. M. and Pulliam H. R.** 2007. Hierarchical analysis of
species distributions and abundance across environmental
gradients. *Ecology.* **88**(12): 3144-3152.

Contact
-------

Ghislain Vieilledent	
Cirad, UPR BSEF		
Campus de Baillarguet	
TA C-105/D		
34398 Montpellier cedex 5	
FRANCE

Skype: ghislain.vieilledent
Email: ghislain(dot)vieilledent(at)cirad(dot)fr   
WWW: <http://ghislain.vieilledent.free.fr>

==> hSDM_1.4.tar.gz: hSDM/README.md <==
hSDM R package
===============

`hSDM` is an R package for estimating parameters of hierarchical
Bayesian species distribution models. Such models allow interpreting
the observations (occurrence and abundance of a species) as a result
of several hierarchical processes including ecological processes
(habitat suitability, spatial dependence and anthropogenic
disturbance) and observation processes (species
detectability). Hierarchical species distribution models are essential
for accurately characterizing the environmental response of species,
predicting their probability of occurrence, and assessing uncertainty
in the model results.

Code and manual
---------------

The last stable version of the `hSDM` R package is officially
available for several operating systems (Unix, Windows and Mac OSX) on
the Comprehensive R Archive Network
([CRAN](http://cran.r-project.org/web/packages/hSDM/index.html)).

Acknowledgments
--------------

We gratefully acknowledge Shanshan Wu for the original C++ code used
in Latimer et al. 2006.

Related publications
--------------------

**Diez J. M. and Pulliam H. R.** 2007. Hierarchical analysis of
species distributions and abundance across environmental
gradients. *Ecology.* **88**(12): 3144-3152.

**Gelfand A. E., Silander J. A., Wu S. S., Latimer A., Lewis P. O.,
Rebelo A. G. and Holder M.** 2006. Explaining species distribution
patterns through hierarchical modeling. *Bayesian Analysis.* **1**(1):
41-92.

**Latimer, A. M.; Wu, S. S.; Gelfand, A. E. & Silander, J. A.** 2006.
Building statistical models to analyze species distributions.
*Ecological Applications.* **16**(1): 33-50.

**MacKenzie, D. I.; Nichols, J. D.; Lachman, G. B.; Droege, S.; Andrew
Royle, J. and Langtimm, C. A.** 2002. Estimating site occupancy rates
when detection probabilities are less than one. *Ecology.*, **83**:
2248-2255.

**Royle, J. A.** 2004. N-mixture models for estimating population size
  from spatially replicated counts. *Biometrics.*, **60**:, 108-115.

Contact
-------

Ghislain Vieilledent	
Cirad, UPR BSEF		
Campus de Baillarguet	
TA C-105/D		
34398 Montpellier cedex 5	
FRANCE

Skype: ghislain.vieilledent
Email: ghislain(dot)vieilledent(at)cirad(dot)fr
WWW: <http://ghislain.vieilledent.free.fr>
